@@ -399,6 +399,9 @@ class ConfigManager:
             "vehicle_monitoring" : None,
             "fire_smoke_detection": None,
             "flare_analysis" : None,
+            "mask_detection": None,
+            "parking_space_detection": None,
+            "car_damage_detection":None,
             "weld_defect_detection" : None,
         }
 
@@ -446,6 +449,13 @@ class ConfigManager:
             return ParkingSpaceConfig
         except ImportError:
             return None
+    def _get_mask_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.mask_detection import MaskDetectionConfig
+            return MaskDetectionConfig
+        except ImportError:
+            return None
 
     def _get_pothole_segmentation_config_class(self):
         """Register a configuration class for a use case."""
@@ -629,6 +639,22 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        elif usecase == "mask_detection":
+            # Import here to avoid circular import
+            from ..usecases.mask_detection import MaskDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = MaskDetectionConfig(
+                category=category or "mask_detection",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "fire_smoke_detection":
             # Import here to avoid circular import
             from ..usecases.fire_detection import FireSmokeConfig
@@ -960,6 +986,11 @@ class ConfigManager:
             from ..usecases.parking_space_detection import ParkingSpaceConfig
             default_config = ParkingSpaceConfig()
             return default_config.to_dict()
+        elif usecase == "mask_detection":
+            # Import here to avoid circular import
+            from ..usecases.mask_detection import MaskDetectionConfig
+            default_config = MaskDetectionConfig()
+            return default_config.to_dict()
 
         elif usecase == "fire_smoke_detection":
             # Import here to avoid circular import
