@@ -26,6 +26,7 @@ from .weld_defect_detection import WeldDefectConfig,WeldDefectUseCase
 
 from .car_damage_detection import CarDamageConfig, CarDamageDetectionUseCase
 from .price_tag_detection import PriceTagConfig, PriceTagUseCase
+from .mask_detection import MaskDetectionConfig, MaskDetectionUseCase
 
 
 __all__ = [
@@ -39,6 +40,7 @@ __all__ = [
     'VehicleMonitoringUseCase',
     'ParkingSpaceUseCase',
     'FireSmokeUseCase',
+    'MaskDetectionUseCase',
     'FlareAnalysisUseCase',
     'PotholeSegmentationUseCase',
     'CarDamageDetectionUseCase',
@@ -57,6 +59,7 @@ __all__ = [
     'PotholeConfig',
     'ColorDetectionConfig',
     'CarDamageConfig',
+    'CarDamageConfig',
     'VehicleMonitoringConfig',
     'FireSmokeConfig',
     'FlareAnalysisConfig',
