@@ -473,7 +473,7 @@ class FaceEmotionUseCase(BaseProcessor):
             human_text = "\n".join(human_text_lines)
 
             event = {
-                "type": "face_emotion_detection",
+                "type": "face_emotion",
                 "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
                 "level": level,
                 "intensity": round(intensity, 1),
@@ -588,7 +588,7 @@ class FaceEmotionUseCase(BaseProcessor):
         human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
-            "type": "face_emotion_detection",
+            "type": "face_emotion_tracking",
             "category": "general",
             "count": total_emotions,
             "insights": insights,
